@@ -37,7 +37,7 @@ The type of response wanted.  By default this returns xml.
 
 =cut
 
-__PACKAGE__->mk_accessors(qw( method params callback ));
+__PACKAGE__->mk_accessors(qw( method params));
 
 sub type {
    my $self = shift;
